@@ -11,10 +11,6 @@
 #' object created with other packages, see details, default is \code{NULL}.
 #' @param verbose logical, if \code{TRUE} shows a progress bar during cross
 #' validation, default is \code{TRUE}.
-#' @param p Deprecated.
-#' @param a Deprecated.
-#' @param rep Deprecated.
-#' @param seed Deprecated.
 #' @param ... Arguments passed to the relative method, see details.
 #'
 #' @details
@@ -40,18 +36,16 @@
 #'     default is \code{floor(sqrt(number of variables))}.
 #'     + ntree: integer. Number of tree to grow, default is 500.
 #'     + nodesize: integer. Minimum size of terminal nodes.
-#' * For the Maxent method, possible arguments are:
+#' * Maxent models are trained using the arguments
+#' \code{"removeduplicates=false"} and \code{"addsamplestobackground=false"}.
+#' Use the function \code{\link{thinData}} to remove duplicates and the function
+#' \code{\link{addSamplesToBg}} to add presence locations to background
+#' locations. For the Maxent method, possible arguments are:
 #'     + reg: numeric. The value of the regularization multiplier, default is 1.
 #'     + fc: character. The value of the feature classes, possible values are
 #'       combinations of "l", "q", "p", "h" and "t", default is "lqph".
 #'     + iter: numeric. Number of iterations used by the MaxEnt algorithm,
 #'       default is 500.
-#'     + extra_args: vector. Extra arguments used to run MaxEnt, default is
-#'       "removeduplicates=false" and "addsamplestobackground=false". In case
-#'       this is not your expected behavior you can assign extra_args = "" or
-#'       you can change or add any other additional arguments extending the
-#'       default settings (e.g. \code{extra_args = c("removeduplicates=true,
-#'       addsamplestobackground=true)"**})
 #' * For the Maxnet method, possible arguments are (for more details see
 #' \code{\link[maxnet]{maxnet}}):
 #'     + reg: numeric. The value of the regularization intensity, default is 1.
@@ -118,27 +112,31 @@
 #' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
 #'                    env = predictors, categorical = "biome")
 #'
-#' # Train a Maxent model
+#' ## Train a Maxent model
 #' model <- train(method = "Maxent", data = data, fc = "l", reg = 1.5,
 #'                iter = 700)
+#' # Add samples to background. This should be done preparing the data before
+#' # training the model without using
+#' data <- addSamplesToBg(data)
+#' model <- train("Maxent, data = data)
 #'
-#' # Train a Maxnet model
+#' ## Train a Maxnet model
 #' model <- train(method = "Maxnet", data = data, fc = "lq", reg = 1.5)
 #'
-#' # Cross Validation
+#' ## Cross Validation
 #' # Create 4 random folds splitting only the presence data
 #' folds <- randomFolds(data, k = 4, only_presence = TRUE)
 #' model <- train(method = "Maxnet", data = data, fc = "l", reg = 0.8,
 #'                folds = folds)
 #'
-#' # Block partition using the ENMeval package
+#' ## Block partition using the ENMeval package
 #' # library(ENMeval)
 #' block_folds <- get.block(occ = data@coords[data@pa == 1, ],
 #'                          bg.coords = data@coords[data@pa == 0, ])
 #' model <- train(method = "Maxnet", data = data, fc = "l", reg = 0.8,
 #'                folds = block_folds)
 #'
-#' # Checkerboard1 partition using the ENMeval package
+#' ## Checkerboard1 partition using the ENMeval package
 #' cb_folds <- get.checkerboard1(occ = data@coords[data@pa == 1, ],
 #'                               env = predictors,
 #'                               bg.coords = data@coords[data@pa == 0, ],
@@ -146,7 +144,7 @@
 #' model <- train(method = "Maxnet", data = data, fc = "l", reg = 0.8,
 #'                folds = cb_folds)
 #'
-#' # Environmental block using the blockCV package
+#' ## Environmental block using the blockCV package
 #' # library(blockCV)
 #' # Create spatial points data frame
 #' library(raster)
@@ -162,7 +160,7 @@
 #' model <- train(method = "Maxnet", data = data, fc = "l", reg = 0.8,
 #'                folds = e_folds)
 #'
-#' # Train presence absence models
+#' ## Train presence absence models
 #' # Prepare presence and absence locations
 #' p_coords <- virtualSp$presence
 #' a_coords <- virtualSp$absence
@@ -170,51 +168,38 @@
 #' data <- prepareSWD(species = "Virtual species", p = p_coords, a = a_coords,
 #'                    env = predictors[[1:5]])
 #'
-#' # Train an Artificial Neural Network model
+#' ## Train an Artificial Neural Network model
 #' model <- train("ANN", data = data, size = 10)
 #'
-#' # Train a Random Forest model
+#' ## Train a Random Forest model
 #' model <- train("RF", data = data, ntree = 300)
 #'
-#' # Train a Boosted Regression Tree model
+#' ## Train a Boosted Regression Tree model
 #' model <- train("BRT", data = data, n.trees = 300, shrinkage = 0.001)
 #'
-#' # Multiple methods trained together with default arguments
+#' ## Multiple methods trained together with default arguments
 #' output <- train(method = c("ANN", "BRT", "RF"), data = data, size = 10)
 #' output$ANN
 #' output$BRT
 #' output$RF
 #'
-#' # Multiple methods trained together passing extra arguments
+#' ## Multiple methods trained together passing extra arguments
 #' output <- train(method = c("ANN", "BRT", "RF"), data = data, size = 10,
 #'                 ntree = 300, n.trees = 300, shrinkage = 0.001)
 #' }
-train <- function(method, data, folds = NULL, verbose = TRUE, p = NULL,
-                  a = NULL, rep = NULL, seed = NULL, ...) {
+train <- function(method, data, folds = NULL, verbose = TRUE, ...) {
 
   l <- length(method)
   output <- vector("list", length = l)
 
   for (i in 1:l) {
     m <- match.arg(method[i], c("Maxent", "Maxnet", "ANN", "RF", "BRT"))
-    f <- paste0("train", m)
+    func <- paste0("train", m)
     ea <- list(...)  # Extra arguments
 
-    # TODO Remove in next release
-    if (!is.null(p) & !is.null(a)) {
-      stop("Argument \"p\" and \"a\" are deprecated, use \"data\" instead.")
-    }
-    if (!is.null(rep))
-      warning("Argument \"rep\" is deprecated and will be removed in the nex ",
-              "release. The number of partition is taken from the \"fold\" ",
-              "argument.")
-    if (!is.null(seed))
-      warning("Argument seed is deprecated and will be removed in the next ",
-              "release.", call. = FALSE)
-
     if (is.null(folds)) {
-      output[[i]] <- do.call(f, args = c(data = data,
-                                         ea[names(ea) %in% formalArgs(f)]))
+      argus <- c(data = data, ea[names(ea) %in% .args_name(func)])
+      output[[i]] <- do.call(func, args = argus)
     } else {
       folds <- .convert_folds(folds, data)
       k <- ncol(folds[[1]])
@@ -229,8 +214,8 @@ train <- function(method, data, folds = NULL, verbose = TRUE, p = NULL,
 
       for (j in 1:k) {
         train <- .subset_swd(data, folds$train[, j])
-        models[[j]] <- do.call(f, c(data = train,
-                                    ea[names(ea) %in% formalArgs(f)]))
+        argus <- c(data = train, ea[names(ea) %in% .args_name(func)])
+        models[[j]] <- do.call(func, args = argus)
         if (verbose)
           pb$tick(1)
       }
