@@ -1,4 +1,5 @@
 skip_on_cran()
+skip_on_appveyor()
 
 m <- SDMtune:::bm_maxent
 m_cv <- SDMtune:::bm_maxent_cv
@@ -21,9 +22,6 @@ test_that("The function raises warnings and errors", {
                "\"test\" argument invalid, use an SWD object.")
   expect_error(auc(m_cv, SDMtune:::t@data),
                "\"test\" argument invalid, use an SWD object.")
-  # TODO Remove next test with next release
-  expect_warning(auc(m, a = SDMtune:::t),
-                 "Argument \"a\" is deprecated and not used anymore, it ")
 })
 
 test_that("The function returns the same result than Maxent software", {
