@@ -1,4 +1,5 @@
 skip_on_cran()
+skip_on_appveyor()
 
 m <- SDMtune:::bm_maxnet
 test <- SDMtune:::t
@@ -32,3 +33,8 @@ test_that("The thresholds start with 0 and end with 1 when th is not passed", {
   expect_equal(cm$th[1], 0)
   expect_equal(cm$th[nrow(cm)], 1)
 })
+
+test_that("Exception is raised", {
+  expect_error(confMatrix(SDMtune:::bm_maxent_cv, type = "cloglog"),
+               "Function available only for SDMmodel objects.")
+})
